==> kubernetes-model-1.0.3-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class ReplicationControllerSpecBuilder extends ReplicationControllerSpecFluent<ReplicationControllerSpecBuilder> implements VisitableBuilder<ReplicationControllerSpec,ReplicationControllerSpecBuilder>{

     ReplicationControllerSpecFluent<?> fluent;
public ReplicationControllerSpecBuilder(){
    this(new ReplicationControllerSpec());
}
public ReplicationControllerSpecBuilder( ReplicationControllerSpecFluent<?> fluent ){
    this(fluent, new ReplicationControllerSpec());
}
public ReplicationControllerSpecBuilder( ReplicationControllerSpecFluent<?> fluent , ReplicationControllerSpec instance ){
    this.fluent = fluent; fluent.withReplicas(instance.getReplicas()); fluent.withSelector(instance.getSelector()); fluent.withTemplate(instance.getTemplate()); 
}
public ReplicationControllerSpecBuilder( ReplicationControllerSpec instance ){
    this.fluent = this; this.withReplicas(instance.getReplicas()); this.withSelector(instance.getSelector()); this.withTemplate(instance.getTemplate()); 
}

public EditableReplicationControllerSpec build(){
    EditableReplicationControllerSpec buildable = new EditableReplicationControllerSpec(fluent.getReplicas(),fluent.getSelector(),fluent.getTemplate());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.13-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerSpecBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class ReplicationControllerSpecBuilder extends ReplicationControllerSpecFluent<ReplicationControllerSpecBuilder> implements VisitableBuilder<ReplicationControllerSpec,ReplicationControllerSpecBuilder>{

     ReplicationControllerSpecFluent<?> fluent;
public ReplicationControllerSpecBuilder(){
    this(new ReplicationControllerSpec());
}
public ReplicationControllerSpecBuilder( ReplicationControllerSpecFluent<?> fluent ){
    this(fluent, new ReplicationControllerSpec());
}
public ReplicationControllerSpecBuilder( ReplicationControllerSpecFluent<?> fluent , ReplicationControllerSpec instance ){
    this.fluent = fluent; fluent.withReplicas(instance.getReplicas()); fluent.withSelector(instance.getSelector()); fluent.withTemplate(instance.getTemplate()); 
}
public ReplicationControllerSpecBuilder( ReplicationControllerSpec instance ){
    this.fluent = this; this.withReplicas(instance.getReplicas()); this.withSelector(instance.getSelector()); this.withTemplate(instance.getTemplate()); 
}

public EditableReplicationControllerSpec build(){
    EditableReplicationControllerSpec buildable = new EditableReplicationControllerSpec(fluent.getReplicas(),fluent.getSelector(),fluent.getTemplate());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ReplicationControllerSpecBuilder that = (ReplicationControllerSpecBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
